<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>AddLayer</name>
    <message>
        <location filename="../AddLayerInit.js" line="+2"/>
        <source>&amp;Add Layer</source>
        <translation>Laag &amp;toevoegen</translation>
    </message>
    <message>
        <location filename="../AddLayer.js" line="+35"/>
        <source>Layer</source>
        <translation>Laag</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Add Layer</source>
        <translation>Laag toevoegen</translation>
    </message>
</context>
<context>
    <name>Layer</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+33"/>
        <source>Default color for new layers:</source>
        <translation>Standaard kleur voor nieuwe lagen:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Default lineweight for layer 0:</source>
        <translation>Standaard lijndikte voor laag 0:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Default color for layer 0:</source>
        <translation>Standaard kleur voor laag 0:</translation>
    </message>
    <message>
        <location line="-45"/>
        <source>Default lineweight for new layers:</source>
        <translation>Standaard lijndikte voor nieuwe lagen:</translation>
    </message>
</context>
</TS>
